@@ -5,7 +5,7 @@ package Data::Scan::Impl::Printer;
 
 # ABSTRACT: Data::Scan printer implementation
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -410,7 +410,8 @@ sub dsread {
       #
       my $i = length($self->indent) x ($self->{_currentLevel} + 2);
       my $deparseopts = ["-sCv'Useless const omitted'"];
-      my $code = 'sub ' . B::Deparse->new($deparseopts)->coderef2text($item);
+      my $code = eval { 'sub ' . B::Deparse->new($deparseopts)->coderef2text($item) };
+      goto CODE_fallback if $@;
       my @code = split(/\R/, $code);
       #
       # First item is not aligned
@@ -436,6 +437,7 @@ sub dsread {
       #
       # Stringify if possible everything that we do not unfold
       #
+      CODE_fallback:
       if (defined($item)) {
         my $string = eval { "$item" }; ## no critic qw/BuiltinFunctions::ProhibitStringyEval/
         if (defined($string)) {
@@ -605,7 +607,7 @@ Data::Scan::Impl::Printer - Data::Scan printer implementation
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -730,6 +732,8 @@ Show hash indices. Default is a true value.
 
 Show deparsed subroutine references. Default is a false value.
 
+If deparse raise an exception, the current item is shown as if with_deparse would be off, i.e. a classic stringification resulting in something like e.g. C<CODE(0x...)>.
+
 =head2 Bool with_methods
 
 Show public, private and inherited methods. Default is a false value.
@@ -872,7 +876,7 @@ If with_methods option is on, L<Class::Inspector> (and not L<Package::Stash> lik
 
 =head1 SEE ALSO
 
-L<Class::Inspector>, L<Data::Scan::Printer>, L<Term::ANSIColor>, L<Win32::Console::ANSI>
+L<B::Deparse>, L<Class::Inspector>, L<Data::Scan::Printer>, L<Term::ANSIColor>, L<Win32::Console::ANSI>
 
 =head1 AUTHOR
 
